@@ -185,7 +185,6 @@ t_rproxy *rproxy_setting(char *line) {
 
 		/* Port
 		 */
-#ifdef ENABLE_IPV6
 		if (*line == '[') {
 			line++;
 			if ((port = strchr(line, ']')) == NULL) {
@@ -201,9 +200,9 @@ t_rproxy *rproxy_setting(char *line) {
 				free(rproxy);
 				return NULL;
 			}
-		} else
-#endif
+		} else {
 			port = strchr(line, ':');
+		}
 
 		if (port != NULL) {
 			*(port++) = '\0';
@@ -546,9 +545,7 @@ int send_request_to_webserver(t_rproxy_webserver *webserver, t_rproxy_options *o
 			}
 
 			forwarded_found = true;
-		}
-
-		if (strncasecmp(http_header->data, hs_x_forwarded_for, 16) == 0) {
+		} else if (strncasecmp(http_header->data, hs_x_forwarded_for, 16) == 0) {
 			/* Add IP to X-Forwarded-For header
 			 */
 
