@@ -43,9 +43,6 @@ static t_keyvalue *variables = NULL;
 #ifdef ENABLE_XSLT
 static char *index_xslt;
 #endif
-#ifdef ENABLE_TLS
-static t_hpkp_data *hpkp_records = NULL;
-#endif
 
 int init_config_module(char *config_dir) {
 	size_t config_dir_len;
@@ -141,7 +138,6 @@ static t_host *new_host(void) {
 	host->ca_certificate      = NULL;
 	host->ca_crl              = NULL;
 	host->random_header_length = -1;
-	host->hpkp_data           = NULL;
 #endif
 #ifdef ENABLE_RPROXY
 	host->rproxy              = NULL;
@@ -274,9 +270,6 @@ static t_binding *new_binding(void) {
 
 	binding->socket               = -1;
 	binding->poll_data            = NULL;
-#ifdef ENABLE_HTTP2
-	binding->accept_http2         = false;
-#endif
 
 	binding->next                 = NULL;
 
@@ -406,7 +399,6 @@ t_config *default_config(void) {
 #endif
 
 #ifdef ENABLE_TLS
-	config->min_tls_version    = MBEDTLS_SSL_MINOR_VERSION_3;
 	config->dh_size            = 2048;
 	config->ca_certificates    = NULL;
 #endif
@@ -623,53 +615,6 @@ static int parse_expires(char *line, int *time, bool *caco_private) {
 	return 0;
 }
 
-#ifdef ENABLE_TLS
-static int parse_hpkp(char *line, t_hpkp_data **hpkp_data) {
-	char *file, *max_age;
-	t_hpkp_data *record;
-	int max_age_i;
-	size_t len;
-
-	if (split_string(line, &file, &max_age, ',') == 0) {
-		if ((len = strlen(max_age)) == 0) {
-			return -1;
-		}
-
-		if ((max_age_i = time_str_to_int(max_age)) == -1) {
-			return -1;
-		}
-	} else {
-		max_age_i = 30 * DAY;
-	}
-
-	record = hpkp_records;
-	while (record != NULL) {
-		if ((strcmp(record->cert_file, file) == 0) && (record->max_age == max_age_i)) {
-			*hpkp_data = record;
-			return 0;
-		}
-
-		record = record->next;
-	}
-
-	if ((*hpkp_data = (t_hpkp_data*)malloc(sizeof(t_hpkp_data))) == NULL) {
-		return -1;
-	}
-
-	if (((*hpkp_data)->cert_file = strdup(file)) == NULL) {
-		return -1;
-	}
-
-	(*hpkp_data)->max_age = max_age_i;
-	(*hpkp_data)->http_header = NULL;
-	(*hpkp_data)->next = hpkp_records;
-
-	hpkp_records = *hpkp_data;
-
-	return 0;
-}
-#endif
-
 static bool replace_variables(char **line) {
 	bool replaced = false;
 	t_keyvalue *variable;
@@ -1256,19 +1201,6 @@ static bool system_setting(char *key, char *value, t_config *config) {
 		if ((config->mimetype_config = strdup(value)) != NULL) {
 			return true;
 		}
-#ifdef ENABLE_TLS
-	} else if (strcmp(key, "mintlsversion") == 0) {
-		if ((strcmp(value, "1.0") == 0) || (strcmp(value, "TLS1.0") == 0)) {
-			config->min_tls_version = MBEDTLS_SSL_MINOR_VERSION_1;
-			return true;
-		} else if ((strcmp(value, "1.1") == 0) || (strcmp(value, "TLS1.1") == 0)) {
-			config->min_tls_version = MBEDTLS_SSL_MINOR_VERSION_2;
-			return true;
-		} else if ((strcmp(value, "1.2") == 0) || (strcmp(value, "TLS1.2") == 0)) {
-			config->min_tls_version = MBEDTLS_SSL_MINOR_VERSION_3;
-			return true;
-		}
-#endif
 #ifdef ENABLE_MONITOR
 	} else if (strcmp(key, "monitorserver") == 0) {
 		if ((monitor_host = new_host()) == NULL) {
@@ -1793,12 +1725,6 @@ static bool host_setting(char *key, char *value, t_host *host) {
 		if (parse_prevent(value, &(host->prevent_xss)) == 0) {
 			return true;
 		}
-#ifdef ENABLE_TLS
-	} else if (strcmp(key, "publickeypins") == 0) {
-		if (parse_hpkp(value, &(host->hpkp_data)) == 0) {
-			return true;
-		}
-#endif
 	} else if (strcmp(key, "requiredbinding") == 0) {
 		if (parse_charlist(value, &(host->required_binding)) == 0) {
 			return true;
@@ -2140,13 +2066,6 @@ static bool directory_setting(char *key, char *value, t_directory *directory) {
 static bool binding_setting(char *key, char *value, t_binding *binding) {
 	char *rest;
 
-#ifdef ENABLE_HTTP2
-	if (strcmp(key, "accepthttp2") == 0) {
-		if (parse_yesno(value, &(binding->accept_http2)) == 0) {
-			return true;
-		}
-	} else
-#endif
 #ifdef HAVE_ACCF
 	if (strcmp(key, "enableaccf") == 0) {
 		if (parse_yesno(value, &(binding->enable_accf)) == 0) {
